@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2015, Adrian Sampson.
 #
@@ -16,8 +17,6 @@
 
 from __future__ import (division, absolute_import, print_function,
                         unicode_literals)
-import ctypes
-
 import os
 import sys
 import re
@@ -701,6 +700,7 @@ def command_output(cmd, shell=False):
         raise subprocess.CalledProcessError(
             returncode=proc.returncode,
             cmd=b' '.join(cmd),
+            output=stdout + stderr,
         )
     return stdout
 
@@ -736,27 +736,52 @@ def open_anything():
     return base_cmd
 
 
-def interactive_open(targets, command=None):
-    """Open the files in `targets` by `exec`ing a new command. (The new
-    program takes over, and Python execution ends: this does not fork a
-    subprocess.)
+def editor_command():
+    """Get a command for opening a text file.
 
-    If `command` is provided, use it. Otherwise, use an OS-specific
-    command (from `open_anything`) to open the file.
+    Use the `EDITOR` environment variable by default. If it is not
+    present, fall back to `open_anything()`, the platform-specific tool
+    for opening files in general.
+    """
+    editor = os.environ.get('EDITOR')
+    if editor:
+        return editor
+    return open_anything()
+
+
+def shlex_split(s):
+    """Split a Unicode or bytes string according to shell lexing rules.
+
+    Raise `ValueError` if the string is not a well-formed shell string.
+    This is a workaround for a bug in some versions of Python.
+    """
+    if isinstance(s, bytes):
+        # Shlex works fine.
+        return shlex.split(s)
+
+    elif isinstance(s, unicode):
+        # Work around a Python bug.
+        # http://bugs.python.org/issue6988
+        bs = s.encode('utf8')
+        return [c.decode('utf8') for c in shlex.split(bs)]
+
+    else:
+        raise TypeError('shlex_split called with non-string')
+
+
+def interactive_open(targets, command):
+    """Open the files in `targets` by `exec`ing a new `command`, given
+    as a Unicode string. (The new program takes over, and Python
+    execution ends: this does not fork a subprocess.)
 
     Can raise `OSError`.
     """
-    if command:
-        command = command.encode('utf8')
-        try:
-            command = [c.decode('utf8')
-                       for c in shlex.split(command)]
-        except ValueError:  # Malformed shell tokens.
-            command = [command]
-        command.insert(0, command[0])  # for argv[0]
-    else:
-        base_cmd = open_anything()
-        command = [base_cmd, base_cmd]
+    # Split the command string into its arguments.
+    try:
+        command = shlex_split(command)
+    except ValueError:  # Malformed shell tokens.
+        command = [command]
+    command.insert(0, command[0])  # for argv[0]
 
     command += targets
 
@@ -769,9 +794,12 @@ def _windows_long_path_name(short_path):
     """
     if not isinstance(short_path, unicode):
         short_path = unicode(short_path)
+
+    import ctypes
     buf = ctypes.create_unicode_buffer(260)
     get_long_path_name_w = ctypes.windll.kernel32.GetLongPathNameW
     return_value = get_long_path_name_w(short_path, buf, 260)
+
     if return_value == 0 or return_value > 260:
         # An error occurred
         return short_path
@@ -815,3 +843,16 @@ def case_sensitive(path):
     lower = _windows_long_path_name(path.lower())
     upper = _windows_long_path_name(path.upper())
     return lower != upper
+
+
+def raw_seconds_short(string):
+    """Formats a human-readable M:SS string as a float (number of seconds).
+
+    Raises ValueError if the conversion cannot take place due to `string` not
+    being in the right format.
+    """
+    match = re.match('^(\d+):([0-5]\d)$', string)
+    if not match:
+        raise ValueError('String not in M:SS format')
+    minutes, seconds = map(int, match.groups())
+    return float(minutes * 60 + seconds)
